function u=flight(z,N,k)
% _____________________________________
%
% FLIGHT
% _____________________________________
% 
% Plots trajectories of airplanes (in different colors)
% using the spline interpolation or polynomial approximation
% (see the assignment text for complete description) 
%    
% Input arguments:
%     z  -  nt x np array, z(j,m) is a complex number x+iy, (x,y) are 
%           coordinates on radar screen of the m-th point at j-th
%           time moment t_j=(j-1)/(nt-1);
%     N  -  coordinates of each airplane should be returned for
%           time moments t_j=(j-1)/(N-1), j=1,...N;
%     k  -  optional parameter. If given then it is the order of the
%           approximating polynomials. Otherwise the cubic spline
%           interpolation should be used.
%
% Output argument:
%     u  -  N x np array, u(j,m) is a complex number x+iy, (x,y) are 
%           coordinates on radar screen of the m-th airplane at time 
%           t_j=(j-1)/(N-1), j=1,...N.
% INITIAL POINTS ARE PLOTTED AS BLACK '*' ON THE SAME SCREEN 
clf;hold on
% np - number of points, nt - number of frames
[nt,np]=size(z);x=real(z);y=imag(z);
if nargin==2
   str='cubic splines';
else
   str=['polynomials of degree ',num2str(k)];
end
string=[num2str(np) ' points, ' num2str(nt) ' frames, ',str];
plot(x,y,'k*');  title(string);  drawnow;
% START TO WRITE YOUR PROGRAM HERE:
warning off;
A=ones(nt,np+1);
R=ones(N,np+1);
u=ones(N,np);
t=0:1/(nt-1):1;
t2=0:1/(N-1):1;
for i=1:nt
    A(i,:)=poly(z(i,:));
end
for m=1:np+1
    if nargin==2
        R(:,m)=spline(t',A(:,m),t2).';
    else
        p=polyfit(t',A(:,m),k);
        for n=1:N
            R(n,m)=polyval(p,t2(n));
        end
    end
end
u(1,:)=roots(R(1,:)).';
for m=2:N
    B=roots(R(m,:)).';
    for n=1:np
        d=inf;
        for i=1:size(B,2)
            if abs(u(m-1,n)-B(i))<d
                d=abs(u(m-1,n)-B(i));
                loc=i;
            end
        end
        u(m,n)=B(loc);
        B=B(1,[1:loc-1,loc+1:size(B,2)]);
    end
end
plot(u)